@@ -5,22 +5,16 @@
 #' @param data Data set containing the list of nations and the variable that we want to plot.
 #' @param ColName Character variable with the name of the variable of interest.
 #' @param CountryName Character variable with the name of the country names column.
-#' @param CountryNameType Character variable with the coding for \code{CountryName}. One of \code{isoa2} (default), \code{isoa3}, or \code{name}.
+#' @param CountryNameType Character variable with the coding for \code{CountryName}. One of \code{isoa2} (default, standing for ISO 3166-1 alpha-2 code), \code{isoa3}, or \code{name}.
 #' @param rangeVal Limit values that are to be defined for the map.
-#' @param longitude Longitude limits. Default is \code{c(-180, 180)} (whole world).
-#' @param latitude Latitude limits. Default is \code{c(-90, 90)} (whole world).
+#' @param longitude Longitude limits. Default is \code{c(-180, 180)} (whole world with crs as EPSG::4326).
+#' @param latitude Latitude limits. Default is \code{c(-90, 90)} (whole world with crs as EPSG::4326).
+#' @param crs Coordinate reference system (EPSG). By default the value is 4326, which corresponds to EPSG::4326 (WGS84)
 #' @param title Title of the plot. Default is no title.
 #' @param legendTitle Title of the legend. Default is the name of the filling variable.
 #' @param annote Do you want to plot country labels (ISO 3166-1 alpha-2 code) on the map? Default is set to \code{FALSE}.
 #' @param div Parameter for modifying the elements dimensions in the map. Usually, it does not need to be modified. Default value is 1.
 #' @param palette_option Character string indicating the palette to be used. Available options range between "A" and "H".
-#' @param save Save the plot in a jpg file?
-#' @param filename Only if is save set to \code{TRUE}. Name of the file.
-#' @param path Only if save is set to \code{TRUE}. Path of the directory where the file is to be saved.
-#' @param width Only if save is set to \code{TRUE}. Width of the file.
-#' @param height Only if save is set to \code{TRUE}. Height of the file.
-#' @param units Only if save is set to \code{TRUE}. Units for width and height. Can be 'cm', 'mm', 'in', or 'px'.
-#' @param scale Only if save is set to \code{TRUE}. Scaling factor for adjusting image dimensions.
 #'
 #' @return a map
 #' @export
@@ -28,8 +22,8 @@
 #' @importFrom countrycode countrycode
 #' @importFrom dplyr "%>%" left_join select filter mutate relocate
 #' @importFrom ggplot2 ggplot geom_sf theme labs scale_fill_viridis_c coord_sf xlab ylab ggtitle
-#'                     aes unit element_text element_blank element_rect geom_text ggsave
-#' @importFrom sf st_centroid st_coordinates st_union
+#'                     aes unit element_text element_blank element_rect geom_text
+#' @importFrom sf st_centroid st_coordinates st_union st_as_sf st_transform st_crs
 #' @importFrom ggfx with_shadow
 #'
 #' @examples
@@ -44,11 +38,9 @@
 #'
 worldplot <- function(data,
                       ColName, CountryName, CountryNameType = "isoa2", rangeVal,
-                      longitude = c(-180, 180) ,latitude = c(-90, 90),
+                      longitude = c(-180, 180) ,latitude = c(-90, 90), crs = 4326,
                       title = "", legendTitle = as.character(ColName),
-                      annote = FALSE, div = 1, palette_option = "D",
-                      save = FALSE, filename = "worldplot.jpg", path = tempdir(),
-                      width = 20, height = 10, units = "cm", scale = 1) {
+                      annote = FALSE, div = 1, palette_option = "D") {
 
   world <- ne_countries(scale = 50, continent = NULL, returnclass = "sf")
 
@@ -98,11 +90,39 @@ worldplot <- function(data,
     xlab('') + ylab('')+
     ggtitle(title)
 
+  if (crs != 4326) {
+    wplot <- wplot +
+      coord_sf(xlim= longitude, ylim= latitude, expand= FALSE, label_axes = 'SW',
+               crs = st_crs(crs))
+  }
+
   if (annote == TRUE) {
 
     world_points <- geometries_data(exclude.iso.na = T,
                                     countries.list = simdata$iso_a2[!is.na(simdata$MapFiller)])
 
+    if (crs != 4326) {
+
+      d <- data.frame(iso_a2 = world_points$iso_a2,
+                      X = world_points$X,
+                      Y =world_points$Y)
+
+      d2 <- st_as_sf(d, coords=c("X","Y"), crs="EPSG:4326" )
+
+      d3 <- st_transform(d2, crs = st_crs(crs))
+
+      d4 <- data.frame(iso_a2 = d3$iso_a2,
+                       X = rep(NA, nrow(d3)),
+                       Y = rep(NA, nrow(d3)))
+
+      for (i in 1: nrow(d3)) {
+        d4[i,c("X","Y")] <- d3$geometry[[i]]
+      }
+
+      world_points <- d4
+
+    }
+
     wplot <- wplot +
       with_shadow(geom_text(data= world_points, aes(x=X, y=Y,label= iso_a2), size= 2/div, color= 'white', fontface= 'bold'),
                   x_offset = 2, y_offset = 2, sigma = 1)
@@ -110,14 +130,6 @@ worldplot <- function(data,
 
   print(wplot)
 
-  if (save == TRUE) {
-    ggplot2::ggsave(filename = filename,
-                   path = path,
-                   width = width,
-                   height = height,
-                   units = units,
-                   dpi = "retina",
-                   scale = scale)
-  }
+  return(wplot)
 
   }
